.g-ldap-server-list-title
  margin 10px 0
  font-size 16px
  color #555
  border-bottom 1px solid #eee

.g-ldap-server-form
  margin-bottom 12px

  .g-ldap-test-result
    margin-top 10px

    &[status="success"]
      color #0a0

    &[status="failure"]
      color #a00
